@@ -13,15 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
-import array
 import binascii
 import os
 
-from os_brick.encryptors import base
-from os_brick import exception
 from oslo_concurrency import processutils
 from oslo_log import log as logging
+from oslo_log import versionutils
+
+from os_brick.encryptors import base
+from os_brick import exception
 
 LOG = logging.getLogger(__name__)
 
@@ -126,18 +126,6 @@ class CryptsetupEncryptor(base.VolumeEncryptor):
                       check_exit_code=True, run_as_root=True,
                       root_helper=self._root_helper)
 
-    def _get_mangled_passphrase(self, key):
-        """Convert the raw key into a list of unsigned int's and then a string
-
-        """
-        # NOTE(lyarwood): This replicates the methods used prior to Newton to
-        # first encode the passphrase as a list of unsigned int's before
-        # decoding back into a string. This method strips any leading 0's
-        # of the resulting hex digit pairs, resulting in a different
-        # passphrase being returned.
-        encoded_key = array.array('B', key).tolist()
-        return ''.join(hex(x).replace('0x', '') for x in encoded_key)
-
     def attach_volume(self, context, **kwargs):
         """Shadow the device and pass an unencrypted version to the instance.
 
@@ -146,19 +134,19 @@ class CryptsetupEncryptor(base.VolumeEncryptor):
         instance is unaware of the underlying encryption due to modifying the
         original symbolic link to refer to the device mounted by dm-crypt.
         """
+        # TODO(lyarwood): Remove this encryptor and refactor the LUKS based
+        # encryptors in the U release.
+        versionutils.report_deprecated_feature(
+            LOG,
+            "The plain CryptsetupEncryptor is deprecated and will be removed "
+            "in a future release. Existing users are encouraged to retype "
+            "any existing volumes using this encryptor to the 'luks' "
+            "LuksEncryptor or 'luks2' Luks2Encryptor encryptors as soon as "
+            "possible.")
         key = self._get_key(context).get_encoded()
         passphrase = self._get_passphrase(key)
 
-        try:
-            self._open_volume(passphrase, **kwargs)
-        except processutils.ProcessExecutionError as e:
-            if e.exit_code == 2:
-                # NOTE(lyarwood): Workaround bug#1633518 by attempting to use
-                # a mangled passphrase to open the device..
-                LOG.info("Unable to open %s with the current passphrase, "
-                         "attempting to use a mangled passphrase to open "
-                         "the volume.", self.dev_path)
-                self._open_volume(self._get_mangled_passphrase(key), **kwargs)
+        self._open_volume(passphrase, **kwargs)
 
         # modify the original symbolic link to refer to the decrypted device
         self._execute('ln', '--symbolic', '--force',
