@@ -307,6 +307,7 @@ class NVMeOFConnector(base.BaseLinuxConnector):
         return self._is_nvme_available(nvme_name)
 
     @utils.trace
+    @utils.connect_volume_prepare_result
     @synchronized('connect_volume', external=True)
     def connect_volume(self, connection_properties):
         """Discover and attach the volume.
@@ -359,6 +360,7 @@ class NVMeOFConnector(base.BaseLinuxConnector):
 
     @utils.trace
     @synchronized('connect_volume', external=True)
+    @utils.connect_volume_undo_prepare_result(unlink_after=True)
     def disconnect_volume(self, connection_properties, device_info,
                           force=False, ignore_errors=False):
         """Flush the volume.
@@ -403,6 +405,7 @@ class NVMeOFConnector(base.BaseLinuxConnector):
 
     @utils.trace
     @synchronized('extend_volume', external=True)
+    @utils.connect_volume_undo_prepare_result
     def extend_volume(self, connection_properties):
         """Update the local kernel's size information.
 
