@@ -12,10 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 import json
-import mock
 import os
+from unittest import mock
+
 import requests
-import six
 
 from os_brick import exception
 from os_brick.initiator.connectors import scaleio
@@ -109,7 +109,7 @@ class ScaleIOConnectorTestCase(test_connector.ConnectorTestCase):
             self.status_code = status_code
 
         def json(self, **kwargs):
-            if isinstance(self._content, six.string_types):
+            if isinstance(self._content, str):
                 return super(ScaleIOConnectorTestCase.MockHTTPSResponse,
                              self).json(**kwargs)
 
@@ -117,7 +117,7 @@ class ScaleIOConnectorTestCase(test_connector.ConnectorTestCase):
 
         @property
         def text(self):
-            if not isinstance(self._content, six.string_types):
+            if not isinstance(self._content, str):
                 return json.dumps(self._content)
 
             self._content = self._content.encode('utf-8')
@@ -269,7 +269,7 @@ class ScaleIOConnectorTestCase(test_connector.ConnectorTestCase):
 
         self.assertRaises(exception.BrickException, self.test_connect_volume)
 
-    @mock.patch('time.sleep')
+    @mock.patch('os_brick.utils._time_sleep')
     def test_error_path_not_found(self, sleep_mock):
         """Timeout waiting for volume to map to local file system"""
         self.mock_object(os, 'listdir', return_value=["emc-vol-no-volume"])
